colour_hdri.utilities.exif Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.utilities.exif Module

## EXIF Manipulation

Exif data manipulation routines based on exiftool:

- `parse_exif_data()`
- `read_exif_tags()`
- `copy_exif_tags()`
- `update_exif_tags()`
- `delete_exif_tags()`
- `read_exif_tag()`
- `write_exif_tag()`

`colour_hdri.utilities.exif.` `parse_exif_data`(data)

  Parses given exif data output from exiftool.

  Parameters: | data (unicode) – Exif data.
  Returns: | Parsed exif data.
  Return type: | list

`colour_hdri.utilities.exif.` `read_exif_tags`(image)

  Returns given image exif image tags.

  Parameters: | image (unicode) – Image file.
  Returns: | Exif tags.
  Return type: | defaultdict

`colour_hdri.utilities.exif.` `copy_exif_tags`(source, target)

  Copies given source image file exif tag to given image target.

  Parameters: | source (unicode) – Source image file. target (unicode) – Target image file.
  Returns: | Definition success.
  Return type: | bool

`colour_hdri.utilities.exif.` `update_exif_tags`(images)

  Updates given images siblings images pairs exif tags.

  Parameters: | images (list) – Image files to update.
  Returns: | Definition success.
  Return type: | bool

`colour_hdri.utilities.exif.` `delete_exif_tags`(image)

  Deletes all given image exif tags.

  Parameters: | image (unicode) – Image file.
  Returns: | Definition success.
  Return type: | bool

`colour_hdri.utilities.exif.` `read_exif_tag`(image, tag)

  Returns given image exif tag value.

  Parameters: | image (unicode) – Image file. tag (unicode) – Tag.
  Returns: | Tag value.
  Return type: | unicode

`colour_hdri.utilities.exif.` `write_exif_tag`(image, tag, value)

  Sets given image exif tag value.

  Parameters: | image (unicode) – Image file. tag (unicode) – Tag. value (unicode) – Value.
  Returns: | Definition success.
  Return type: | bool